@@ -66,14 +66,15 @@ class Progress():
                 clean (bool): Whether to erase the progress printed or not
         """
 
-        # Wait for some time to print any unprinted changes
-        time.sleep(self.refresh_time)
+        try:
+            # Wait for some time to print any unprinted changes
+            time.sleep(self.refresh_time)
+        except KeyboardInterrupt:
+            pass
+
         # Stop the printing thread
         self._stopped = True
-
         if clean:
-            # Wait for some time before cleaning
-            time.sleep(self.refresh_time)
             self._clean()
 
 
@@ -87,7 +88,8 @@ class ProgressBar(Progress):
         ['=', 'X'],
     ]
 
-    def __init__(self, msg: str = '', refresh_time: float = 0.2, size: int = 40, style: Union[int, list[int]] = 0) -> None:
+    def __init__(
+            self, msg: str = '', refresh_time: float = 0.2, size: int = 40, style: Union[int, list[int]] = 0) -> None:
         """
             Prints a progress bar to the cli
 
@@ -97,7 +99,7 @@ class ProgressBar(Progress):
                 refresh_time (float): The time interval after which progress will be updated
 
                 size (int): The size of the progress bar (the number of max characters to print)
-                
+
                 style (int/list[int]): The style to use (0-5) or the list of phases, print ProgressBar.STYLES to see all the provided styles & phases
         """
         super().__init__(refresh_time)
@@ -127,7 +129,8 @@ class ProgressBar(Progress):
 
         print(Cursor.move_down, end='')
         while not self._stopped:
-            progress = "[" + (int(self.percent_completed * self.size/100) * self._style[1]).ljust(self.size, self._style[0]) + "]"
+            progress = "[" + (int(self.percent_completed * self.size/100)
+                              * self._style[1]).ljust(self.size, self._style[0]) + "]"
             self._clean()
             print(self.__msg.format(progress=progress))
 
@@ -142,7 +145,7 @@ class Spinner(Progress):
         ['⣾', '⣷', '⣯', '⣟', '⡿', '⢿', '⣻', '⣽'],
     ]
 
-    def __init__(self, msg: str = '', refresh_time: float = 0.2, style: Union[int,list[int]] = 3) -> None:
+    def __init__(self, msg: str = '', refresh_time: float = 0.2, style: Union[int, list[int]] = 3) -> None:
         """
             Prints infinite spinning spinner to the cli
 
